@@ -6,11 +6,15 @@ from novelsave.core.entities.novel import Novel, Asset
 
 
 class BasePathService(ABC):
-
     @abstractmethod
     def divide(self, r_path: Path) -> Path:
         """add additional sub folder to the parent depending on the file type"""
 
+    @property
+    @abstractmethod
+    def config_path(self) -> Path:
+        """Absolute path to configurations"""
+
     @abstractmethod
     def novel_save_path(self, novel: Novel) -> Path:
         """:return absolute path to novel save directory"""
