@@ -1,10 +1,10 @@
 from abc import ABC, abstractmethod
+from typing import List
 
 from . import BaseSourceGateway, BaseMetaSourceGateway
 
 
 class BaseSourceService(ABC):
-
     @property
     @abstractmethod
     def current_version(self) -> str:
@@ -27,3 +27,7 @@ class BaseSourceService(ABC):
 
         :raises MetaDataSourceNotFoundException: if no source if available for the url
         """
+
+    @abstractmethod
+    def get_novel_sources(self) -> List[BaseSourceGateway]:
+        """Get all the supported sources"""
