@@ -14,6 +14,7 @@ class NSError(Exception):
 @dataclass
 class CookieBrowserNotSupportedException(NSException):
     """the specified browser does not support cookie extraction"""
+
     browser: str
 
 
@@ -26,5 +27,17 @@ class ContentUpdateFailedException(NSException):
 @dataclass
 class SourceNotFoundException(NSException):
     """source for the url was not found"""
+
     url: str
 
+
+class ToolException(NSException):
+    """Generic exception that is raised from command-line tools"""
+
+
+class PackagingException(NSException):
+    """Generic exception that is thrown during packaging"""
+
+
+class RequirementException(NSException):
+    """Raised when a particular requirement is not met"""
