@@ -8,7 +8,6 @@ from novelsave.utils.adapters import SourceAdapter
 
 
 class MetaSourceGateway(BaseMetaSourceGateway):
-
     def __init__(self, meta_source: MetaSource, source_adapter: SourceAdapter):
         self.meta_source = meta_source
         self.source_adapter = source_adapter
@@ -20,7 +19,4 @@ class MetaSourceGateway(BaseMetaSourceGateway):
     def metadata_by_url(self, url: str) -> List[MetaDataDTO]:
         metadata = self.meta_source.retrieve(url)
 
-        return [
-            self.source_adapter.metadata_to_internal(m)
-            for m in metadata
-        ]
+        return [self.source_adapter.metadata_to_internal(m) for m in metadata]
