@@ -9,7 +9,7 @@ def display_value(data: MetaData):
     except json.JSONDecodeError:
         others = {}
 
-    others = [f'{key}={value}' for key, value in others.items()]
-    postfix = f'(' + ', '.join(others) + ')' if others else ''
+    others = [f"{key}={value}" for key, value in others.items()]
+    postfix = "(" + ", ".join(others) + ")" if others else ""
 
-    return f'{data.value}{postfix}'
+    return f"{data.value}{postfix}"
